const fs = require('fs');
const yesno = require('yesno');
const name = process.argv[2];
const workingDir = process.cwd();

let componentTemplate = `// src/components/${name}/index.js
import React, { PropTypes, Component } from 'react';
import classnames from 'classnames';

import './style.css';

export default class ${name} extends Component {
  // static propTypes = {}
  // static defaultProps = {}
  // state = {}

  render() {
    const { className, ...props } = this.props;
    return (
      <div className={classnames('${name}', className)} {...props}>
        <h1>
          ${name}
        </h1>
      </div>
    );
  }
}`;

const dataHandler = (cb) => {
  return (err, data) => {
    if (err) {
      console.log('There was an error:', err);
    } else {
      cb(data);
    }
  }
};

const writeComponent = (cb) => {
  let finished = dataHandler(cb);
  fs.writeFile(name + '/index.js', componentTemplate, finished);
};

const writeStyle = (cb) => {
  let finished = dataHandler(cb);
  fs.writeFile(name + '/style.css', '', finished);
};


fs.readdir(workingDir + '/' + name, (err, data) => {
  if (!err) {
    yesno.ask('\nClass name already written. Shall I overwrite? [y/n]\n', true, (ok) => {
      if(ok) {
        writeComponent(() => {
          writeStyle(() => {
            console.log(`Component class ${name} written.\n`);
          });
        });
      } else {
        console.log("Cancelled.");
      }
      process.stdin.unref();
    });
  } else {
    fs.mkdir(workingDir + '/' + name, (err, data) => {
      writeComponent(() => {
        writeStyle(() => {
          console.log(`Component class '${name}' written.\n`);
        });
      });
    });
  }
});